% Basic RBC Model
% + with physical capital
% gauthier[at]vermandel.fr


close all;
%format long

%----------------------------------------------------------------
% 1. Defining variables
%----------------------------------------------------------------

var y c k i h w r z a g;
varexo e_a e_g;

parameters	beta alpha delta sigmaC sigmaL gy
			rho_a rho_g
			R Y C Z I
			;

%----------------------------------------------------------------
% 2. Calibration
%----------------------------------------------------------------

% Loading calibration
@#include "calibration.mod"

%----------------------------------------------------------------
% 3. Model
%----------------------------------------------------------------
model(linear);
    %% Household
	% Euler
	sigmaC*(c(+1)-c)=r;
	% hours supply
	w = (1/sigmaL)*h + sigmaC*c;

	%% Capital supply
	% No arbitrage Bonds-Capital
	R*r = Z*z(+1);
	% Capital law of motion
	delta*i = k-(1-delta)*k(-1);

    % Intermediary firms
	% Production function
	y = a + alpha*k(-1) + (1-alpha)*h;
	% Inputs Cost minimization
	z = y - k(-1);
	w + h = z + k(-1);
    % Resources constraint
	Y*y = C*c + I*i + gy*Y*g ;
	
    % Exogenous shocks
	a = rho_a*a(-1) + e_a;
	g = rho_g*g(-1) + e_g;
end;

%----------------------------------------------------------------
% 4. Computation
%----------------------------------------------------------------
check;
steady;


stoch_simul(order = 1,irf=30) y c k i w h r;